==> customer-link-project-api-1.0.11-20231114.094237-7-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app95640/dto/result/ZyrsUserInfoDto.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app95640.dto.result;

public class ZyrsUserInfoDto {
    /**
     * 是否可以中奖  0：否、1：是
     */
    private String canLottery;
    /**
     * 用户当前积分值
     */
    private String creditCount;
    /**
     * 是否为代理人，0：否、1：是
     */
    private String isAgent;
    /**
     * 代理人编号
     */
    private String agentNo;
    /**
     * 客户渠道(KA：个险、GA：经代、BA：银保、RA：续期、DB：团
     * 险、CA：关联)
     */
    private String clientChannel;
    /**
     * 脱敏的手机号码，中间4位*号显示
     */
    private String phoneNumber;

    public String getCanLottery() {
        return canLottery;
    }

    public void setCanLottery(String canLottery) {
        this.canLottery = canLottery;
    }

    public String getCreditCount() {
        return creditCount;
    }

    public void setCreditCount(String creditCount) {
        this.creditCount = creditCount;
    }

    public String getIsAgent() {
        return isAgent;
    }

    public void setIsAgent(String isAgent) {
        this.isAgent = isAgent;
    }

    public String getAgentNo() {
        return agentNo;
    }

    public void setAgentNo(String agentNo) {
        this.agentNo = agentNo;
    }

    public String getClientChannel() {
        return clientChannel;
    }

    public void setClientChannel(String clientChannel) {
        this.clientChannel = clientChannel;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }
}

==> customer-link-project-api-1.1.30-sources.jar: cn/com/duiba/customer/link/project/api/remoteservice/app95640/dto/result/ZyrsUserInfoDto.java <==
package cn.com.duiba.customer.link.project.api.remoteservice.app95640.dto.result;

public class ZyrsUserInfoDto {
    /**
     * 是否可以中奖  0：否、1：是
     */
    private String canLottery;
    /**
     * 用户当前积分值
     */
    private String creditCount;
    /**
     * 是否为代理人，0：否、1：是
     */
    private String isAgent;
    /**
     * 代理人编号
     */
    private String agentNo;
    /**
     * 客户渠道(KA：个险、GA：经代、BA：银保、RA：续期、DB：团
     * 险、CA：关联)
     */
    private String clientChannel;
    /**
     * 脱敏的手机号码，中间4位*号显示
     */
    private String phoneNumber;
    /**
     * 用户星级
     * 客户等级（V1~V7)
     */
    private String memberSystemLevel;
    /**
     * 客户类型（1：客户，2：准客户，3：纯新客户）
     */
    private String clientType;

    public String getMemberSystemLevel() {
        return memberSystemLevel;
    }

    public void setMemberSystemLevel(String memberSystemLevel) {
        this.memberSystemLevel = memberSystemLevel;
    }

    public String getCanLottery() {
        return canLottery;
    }

    public void setCanLottery(String canLottery) {
        this.canLottery = canLottery;
    }

    public String getCreditCount() {
        return creditCount;
    }

    public void setCreditCount(String creditCount) {
        this.creditCount = creditCount;
    }

    public String getIsAgent() {
        return isAgent;
    }

    public void setIsAgent(String isAgent) {
        this.isAgent = isAgent;
    }

    public String getAgentNo() {
        return agentNo;
    }

    public void setAgentNo(String agentNo) {
        this.agentNo = agentNo;
    }

    public String getClientChannel() {
        return clientChannel;
    }

    public void setClientChannel(String clientChannel) {
        this.clientChannel = clientChannel;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public String getClientType() {
        return clientType;
    }

    public void setClientType(String clientType) {
        this.clientType = clientType;
    }
}
